/**
 * 
 */
package net.bigeon.gclc.swt.io;

/*-
 * #%L
 * GCLC swt
 * %%
 * Copyright (C) 2015 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */

import java.io.IOException;

import org.eclipse.swt.widgets.Text;

import net.bigeon.gclc.manager.PipedConsoleInput;
import net.bigeon.gclc.swt.api.ConsoleDelayIO;

/** The object managing the console input.
 * 
 * @author Emmanuel Bigeon */
public final class ConsoleInputManager implements ConsoleDelayIO {

    private final Text        text;
    private PipedConsoleInput input;

    /** Create a managing object.
     * 
     * @param text the text */
    public ConsoleInputManager(final Text text) {
        super();
        this.text = text;
    }

    /* (non-Javadoc)
     * @see net.bigeon.gclc.swt.ConsoleDelayIO#setInput(java.lang.String) */
    @Override
    public void setInput(final String string) {
        text.setText(string);
        text.setSelection(string.length());
    }

    /* (non-Javadoc)
     * @see net.bigeon.gclc.swt.ConsoleDelayIO#getInput() */
    @Override
    public String getInput() {
        return text.getText();
    }

    /* (non-Javadoc)
     * @see net.bigeon.gclc.swt.ConsoleDelayIO#validateInput() */
    @Override
    public void validateInput() throws IOException {
        input.type(text.getText());
    }

    /** Set the input to control.
     * 
     * @param input the input */
    public void setManager(final PipedConsoleInput input) {
        this.input = input;
    }

    /** Get the text component containing the currently set input.
     * 
     * @return the text */
    public Text getText() {
        return text;
    }
}
