/**
 * 
 */
package net.bigeon.gclc.swt.tools;

/*-
 * #%L
 * GCLC swt
 * %%
 * Copyright (C) 2015 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */

import java.io.BufferedReader;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.eclipse.swt.widgets.Label;

/** The runnable forwarding prompts from a buffered input to a label.
 * 
 * @author Emmanuel Bigeon */
public class PromptReadingRunnable implements Runnable {

    /** The logger for this class. */
    private static final Logger LOGGER = Logger
            .getLogger(PromptReadingRunnable.class.getName());

    /** The reader providing the succession of prompts */
    private final BufferedReader reader;
    /** The label. */
    private final Label          view;
    /** The running status. */
    private boolean              running = true;

    /** The updating runnable implementation.
     * 
     * @author Emmanuel Bigeon */
    private static class LabelUpdater implements Runnable {
        /** The label to update. */
        private final Label  label;
        /** The text to set. */
        private final String content;

        /** Create the updating runnable.
         * 
         * @param label the label
         * @param content the content */
        public LabelUpdater(final Label label, final String content) {
            super();
            this.label = label;
            this.content = content;
        }

        /* (non-Javadoc)
         * @see java.lang.Runnable#run() */
        @Override
        public void run() {
            label.setText(content);
        }
    }

    /** Create the prompt flow updating runnable.
     * 
     * @param reader the reader
     * @param view the view to update on lines. */
    public PromptReadingRunnable(final BufferedReader reader, final Label view) {
        super();
        this.reader = reader;
        this.view = view;
    }

    /* (non-Javadoc)
     * @see java.lang.Runnable#run() */
    @Override
    public void run() {
        String prompt;
        try {
            while (isRunning() && (prompt = reader.readLine()) != null) {
                view.getDisplay().syncExec(new LabelUpdater(view, prompt));
            }
        } catch (final IOException e) {
            LOGGER.log(Level.INFO, "Prompt cannot be read, or was prematuraly closed", e);
        }
    }

    /** Get the running state.
     * 
     * @return the running */
    public synchronized boolean isRunning() {
        return running;
    }

    /** Set the running state.
     * 
     * @param running the running to set */
    public synchronized void setRunning(final boolean running) {
        this.running = running;
    }

    /** Get the prompt flow.
     * 
     * @return the reader */
    public BufferedReader getReader() {
        return reader;
    }
}
