/*
 * Copyright Bigeon Emmanuel (2014)
 *
 * emmanuel@bigeon.fr
 *
 * This software is a computer program whose purpose is to
 * provide a generic framework for console applications.
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * gclc:net.bigeon.gclc.ExitCommand.java
 * Created on: Jun 8, 2016
 */
package net.bigeon.gclc.command.base;

/*-
 * #%L
 * Generic Command Ligne console
 * %%
 * Copyright (C) 2014 - 2018 bigeon.fr
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */
import java.io.IOException;

import net.bigeon.gclc.ConsoleApplication;
import net.bigeon.gclc.command.ICommand;
import net.bigeon.gclc.manager.ConsoleInput;
import net.bigeon.gclc.manager.ConsoleOutput;
import net.bigeon.gclc.prompt.CLIPrompterMessages;

/** A command to exit a {@link ConsoleApplication}.
 *
 * @author Emmanuel BIGEON */
public class ExitCommand implements ICommand {
    /** The exit command manual message key. */
    private static final String      EXIT_MAN = "exit.man"; //$NON-NLS-1$
    /** The tip of the exit command. */
    private static final String      EXIT     = "exit.tip"; //$NON-NLS-1$
    /** The application that will be exited when this command runs. */
    private final ConsoleApplication app;
    /** The exit command name. */
    private final String             name;

    /** Create the exiting command.
     *
     * @param name the name of the command
     * @param app the application to exit */
    public ExitCommand(final String name, final ConsoleApplication app) {
        this.name = name;
        this.app = app;
    }

    /** The actions to take before exiting.
     * <p>
     * This method is intended to be overriden by sub classes. */
    protected void beforeExit() {
        // Do nothing by default
    }

    @Override
    public final void execute(final ConsoleOutput output, final ConsoleInput input,
            final String... args) {
        beforeExit();
        app.exit();
    }

    /* (non-Javadoc)
     * @see net.bigeon.gclc.command.ICommand#getCommandName() */
    @Override
    public final String getCommandName() {
        return name;
    }

    @Override
    public final void help(final ConsoleOutput manager, final String... args)
            throws IOException {
        manager.println(CLIPrompterMessages.getString(EXIT_MAN, (Object[]) args));
    }

    @Override
    public final String tip() {
        return CLIPrompterMessages.getString(EXIT);
    }
}
