package net.bigeon.gclc.utils;

/*-
 * #%L
 * Generic Command Ligne console
 * %%
 * Copyright (C) 2014 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;

import java.io.IOException;

import org.junit.Test;

import net.bigeon.gclc.manager.ConsoleInput;
import net.bigeon.gclc.manager.EmptyInput;
import net.bigeon.gclc.tools.ConstantString;

public class EmptyInputTest {

    @Test
    public void testClose() throws IOException {
        final ConsoleInput input = EmptyInput.INSTANCE;
        // several close operation shold create no error
        input.close();
        input.close();
        assertFalse("This source input should never be closed", input.isClosed());
    }

    @Test
    public void testGetPrompt() {
        
        final ConsoleInput input = EmptyInput.INSTANCE;
        final String init = input.getPrompt().get();
        input.setPrompt("some prompt different from "+init);
        assertEquals("Prompts should not be changed", init, input.getPrompt().get());
        
        input.setPrompt(new ConstantString("some other prompt different from "+init));
        assertEquals("Prompts should not be changed", init, input.getPrompt().get());
    }

    @Test
    public void testInterruptPrompt() {
        // Nothing to test, really...
        final ConsoleInput input = EmptyInput.INSTANCE;
        // several close operation shold create no error
        input.interruptPrompt();
        assertFalse("This source input should never be closed", input.isClosed());
    }

    @Test
    public void testIsClosed() throws IOException {
        final ConsoleInput input = EmptyInput.INSTANCE;
        // several close operation shold create no error
        assertFalse("This source input should never be closed", input.isClosed());
        input.close();
        assertFalse("This source input should never be closed", input.isClosed());
        input.close();
        assertFalse("This source input should never be closed", input.isClosed());
    }

    @Test
    public void testPrompt() throws IOException {
        final ConsoleInput input = EmptyInput.INSTANCE;
        // several close operation shold create no error
        assertEquals("Any prompt should return the empty value", "", input.prompt());
        assertEquals("Any prompt should return the empty value", "", input.prompt(0));
        assertEquals("Any prompt should return the empty value", "", input.prompt(12));
        assertEquals("Any prompt should return the empty value", "", input.prompt("Test"));
        assertEquals("Any prompt should return the empty value", "", input.prompt("Test", 0));
        assertEquals("Any prompt should return the empty value", "", input.prompt("Test", 12));
    }
}
